@@ -1,4 +1,11 @@
+/*
+ * free.c	- show free whatever
+ *
+ * Copyright (c) 1992 Branko Lankester
+ *
+ */
 
+#define __KERNEL__
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/mman.h>
