@@ -24,6 +24,7 @@
 #include <arpa/inet.h>
 #include <linux/fs.h>
 #include <linux/mm.h>
+#include <fcntl.h>
 #include "ps.h"
 #include "psdata.h"
 
@@ -131,10 +132,19 @@ main(int argc, char *argv[])
 	    add_file(*argv++);
     }
     if (all && !numeric) {
+	FILE *ifp;
+
 	add_file("/");
 	add_dir("/dev");
 	add_dir("/lib");
-	add_dir("/lib/elf");
+	add_dir("/usr/lib");
+	if ((ifp = fopen("/etc/ld.so.conf", "r")) != NULL) {
+	    char dir[PATH_MAX];
+	    while (fgets(dir, sizeof(dir), ifp)) {
+		dir[strlen(dir) - 1] = '\0';
+		add_dir(dir);
+	    }
+	}
     }
 
     mmap_init();
