@@ -73,15 +73,15 @@ show_m(struct task_struct *task)
     int size=0, resident=0;
     int wr=0, dirty=0, acc=0, share=0, trs=0, lrs=0;
     int sh_lib=0, dt=0;
-    int tpag = task->mm->end_code / PAGE_SIZE;
+    int tpag = task->mm->start_code / PAGE_SIZE;
     int ndup = 0;
 
     if (memmap == NULL)
 	get_memmap();
 
-    data_pag = task->mm->end_code/PAGE_SIZE;
-    bss_pag = task->mm->end_data/PAGE_SIZE;
-    brk_pag = (task->mm->brk+0xfff) / PAGE_SIZE;
+    data_pag = task->mm->end_code / PAGE_SIZE;
+    bss_pag = task->mm->end_data / PAGE_SIZE;
+    brk_pag = (task->mm->brk + PAGE_SIZE - 1) / PAGE_SIZE;
 
     printf("\nPid %d: %-8.8s\n", task->pid, task->comm);
     pdir = task->tss.cr3 + (task->mm->start_code >> 20);
