@@ -34,18 +34,27 @@
 #define	PS_Y	8	/* system call */
 
 char *hdrs[] = {
+/* default */
 "  PID TTY     STAT  TIME COMMAND",
+/* `l' */
 "  UID   PID  PPID PRI  NI SIZE  RSS WCHAN      STAT  TTY       TIME COMMAND",
+/* `u' */
 "USER       PID %CPU %MEM SIZE  RSS TTY     STAT  START   TIME COMMAND",
+/* `j' */
 " PPID   PID  PGID   SID TTY     TPGID  STAT   UID   TIME COMMAND",
+/* `s' */
 #ifdef OLD_SIG_FMT
 "  UID   PID SIGNAL   BLOCKED  IGNORED  CAUGHT   STAT  TTY       TIME COMMAND",
 #else
 "  UID   PID 12345678901234567890123456789012 STAT  TTY       TIME COMMAND",
 #endif
+/* `v' */
 "  PID TTY     STAT   TIME PAGEIN TSIZ DSIZ  RSS   LIM %MEM COMMAND",
+/* `m' */
 "  PID TTY     MAJOR MINOR  TRS  DRS SIZE SWAP  RSS SHRD  LIB  DT COMMAND",
+/* `x' */
 " F   PID    STACK      ESP      EIP TMOUT ALARM STAT  TTY       TIME COMMAND",
+/* `y' */
 "  PID TTY     STAT      EIP SYSTEM CALL                      TIME COMMAND",
 };
 
@@ -598,7 +607,7 @@ show_vm(char *s, struct task_struct *task, reg_t *stack)
     s += strlen(s);
     s += sprintf(s, " %6ld %4ld %4ld %4ld ",
 	task->mm->maj_flt + (Sum ? task->mm->cmaj_flt : 0),
-	task->mm->end_code / 1024,
+	(task->mm->end_code - task->mm->start_code) / 1024,
 	SIZE(task, stack), task->mm->rss*4);
     if (task->rlim[RLIMIT_RSS].rlim_cur == RLIM_INFINITY)
 	s += sprintf(s, "   xx ");
@@ -619,7 +628,6 @@ show_m(char *s, struct task_struct *task, reg_t *stack)
 	dev_to_tty(TASK_TTY(task)),
 	task->mm->maj_flt + (Sum ? task->mm->cmaj_flt : 0),
 	task->mm->min_flt + (Sum ? task->mm->cmin_flt : 0),
-	/*task->end_code / 4096 << pg_shift,*/
 	mi->trs << pg_shift,
 	mi->drs << pg_shift,
 	mi->size << pg_shift, 
