@@ -8,15 +8,6 @@
 #include <linux/tty.h>
 #include <linux/sched.h>
 
-#include <linux/mm.h>
-#include <asm/page.h>
-#include <asm/pgtable.h>
-
-#define PAGE_ACCESSED	_PAGE_ACCESSED
-#define PAGE_DIRTY	_PAGE_DIRTY
-#define PAGE_PRESENT	_PAGE_PRESENT
-#define PAGE_RW		_PAGE_RW
-
 extern unsigned long nr_pages;
 
 extern int show_env;	/* -e flag */
@@ -44,7 +35,8 @@ extern caddr_t kbase;
 #define	SSIZE(stack)	(KSTK_ESP(stack) ? _SSIZE(stack) : 0)
 
 #define	VSIZE(task,stack) ((task)->pid == 0 ? 0 : \
-			  (((task)->mm->brk + 1023 + SSIZE(stack)) / 1024))
+			  (((task)->mm->brk - (task)->mm->start_code + 1023 + \
+			  SSIZE(stack)) / 1024))
 #define	SIZE(task,stack)  ((task)->pid == 0 ? 0 : \
 			  (((task)->mm->brk - (task)->mm->end_code + 1023 + \
 			  SSIZE(stack)) / 1024))
