@@ -4,21 +4,11 @@
  * Copyright (c) 1992 Branko Lankester
  *
  */
-#define __KERNEL__
-#include <sys/types.h>
-#include <termios.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <string.h>
-#include <pwd.h>
-#include <errno.h>
-#include <ctype.h>
-#include <time.h>
-#include <sys/ioctl.h>
-#include <linux/sched.h>
-#include <linux/ptrace.h>
 #include <fcntl.h>
+#include <string.h>
 #include <sys/utsname.h>
 #include "ps.h"
 #include "psdata.h"
@@ -120,6 +110,11 @@ k_addr(char *sym)
     key.name = sym - vars.strings;
     p = (struct sym_s *) bsearch(&key, vars.tbl, vars.nsym,
 				 sizeof(struct sym_s), varcmp);
+    if (p == NULL && *sym == '_') {
+	key.name++;
+	p = (struct sym_s *) bsearch(&key, vars.tbl, vars.nsym,
+				     sizeof(struct sym_s), varcmp);
+    }
     if (Debug && p == NULL)
 	fprintf(stderr, "symbol '%s' not found\n", sym);
     return(p ? p->addr : -1);
