@@ -125,13 +125,12 @@
 	{ 1, 0, "adjtimex"},		/* 124 */
 	{ 3, 02, "mprotect"},		/* 125 */
 	{ 3, 01, "sigprocmask"},	/* 126 */
-	/****/
 	{ 2, 02, "create_module"},	/* 127 */
-	{ 4, 0, "init_modlule"},	/* 128 */
+	{ 4, 04, "init_module"},	/* 128 */
 	{ 1, 0, "delete_module"},	/* 129 */
 	{ 1, 0, "get_kernel_syms"},	/* 130 */
-	{ 3, 0, "quota_ctl"},		/* 131 */
-	{ 0, 0, "getpgid"},		/* 132 */
+	{ 4, 04, "quotactl"},		/* 131 */
+	{ 1, 01, "getpgid"},		/* 132 */
 	{ 1, 01, "fchdir"},		/* 133 */
-	{ 2, 03, "bdflush"},		/* 134 */
-	{ 3, 0, "sysfs"},		/* 135 */
+	{ 2, 01, "bdflush"},		/* 134 */
+	{ 2, 01, "sysfs"},		/* 135 */
