@@ -622,7 +622,7 @@ do_it(struct task_struct *task, reg_t *stack, int num)
 			sprintf(tmp, "%6ld ", task->mm->maj_flt);
 			break;
 		case P_TSIZ:
-			sprintf(tmp, "%5ld ", task->mm->end_code / 1024);
+			sprintf(tmp, "%5ld ", (task->mm->end_code - task->mm->start_code) / 1024);
 			break;
 		case P_DSIZ:
 			sprintf(tmp, "%5ld ", SIZE(task, stack));
