@@ -4,23 +4,13 @@
  * Copyright (c) 1992 Branko Lankester
  *
  */
-#define __KERNEL__
-#include <sys/types.h>
-#include <termios.h>
 #include <stdio.h>
+#include <a.out.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <string.h>
-#include <pwd.h>
-#include <errno.h>
-#include <ctype.h>
-#include <time.h>
-#include <sys/ioctl.h>
-#include <linux/sched.h>
-#include <linux/ptrace.h>
-#include <a.out.h>
 #include <dirent.h>
 #include <fcntl.h>
+#include <string.h>
 #include <limits.h>
 #include <sys/stat.h>
 #include <sys/utsname.h>
@@ -35,6 +25,8 @@
 static update_psdb(char *syspath);
 static read_nlist(char *systemfile);
 static write_tbl(int fd, struct dbtbl_s *dbtbl, struct tbl_s *tbl);
+static int nlist_addrcmp(const void *p1, const void *p2);
+static int read_ascii_nlist(int fd);
 
 static struct nlist *namelist;
 static int nsym;
@@ -133,11 +125,21 @@ read_nlist(char *systemfile)
     int fd;
     struct exec hdr;
     unsigned symsize, size;
+    char hex[9];
+    char *endpos;
 
     if ((fd = open(systemfile, O_RDONLY)) < 0) {
 	perror(systemfile);
 	exit(1);
     }
+    if (read(fd, hex, sizeof(hex)) != sizeof(hex)) {
+	perror(systemfile);
+	exit(1);
+    }
+    lseek(fd, 0L, SEEK_SET);
+    strtoul(hex, &endpos, 16);
+    if (endpos == hex + 8)
+	return(read_ascii_nlist(fd));
     if (read(fd, (char *) &hdr, sizeof(hdr)) != sizeof(hdr)) {
 	perror(systemfile);
 	exit(1);
@@ -151,7 +153,7 @@ read_nlist(char *systemfile)
 	exit(1);
     }
     if ((data_start = N_DATOFF(hdr)) == 0) {
-        fprintf(stderr, "%s has no data\n", systemfile);
+	fprintf(stderr, "%s has no data\n", systemfile);
 	exit(1);
     }
     lseek(fd, N_STROFF(hdr), SEEK_SET);
@@ -173,6 +175,83 @@ read_nlist(char *systemfile)
     return(0);
 }
 
+struct address_entry {
+	unsigned long address;
+	int type;
+	char *symbol;
+	struct address_entry *next;
+};
+
+static int
+read_ascii_nlist(int fd)
+{
+    FILE *fp = fdopen(fd, "r");
+    char str[256];
+    char symbol[128];
+    struct address_entry *list = 0;
+    struct address_entry *entry;
+    unsigned symsize, size;
+    int i;
+    char *stringpos;
+
+    nsym = stringsize = 0;
+    while (fgets(str, sizeof(str), fp)) {
+	unsigned long address;
+	char type;
+
+	if (sscanf(str, "%lx %c %s", &address, &type, symbol) != 3) {
+	    fprintf(stderr, "not a map file\n");
+	    exit(1);
+	}
+	entry = (struct address_entry *) xmalloc(sizeof(struct address_entry));
+	entry->address = address;
+	if (type == 'T' || type == 't')
+	    entry->type = N_TEXT;
+	else if (type == 'D' || type == 'd')
+	    entry->type = N_DATA;
+	else if (type == 'B' || type == 'b')
+	    entry->type = N_BSS;
+	else
+	    entry->type = 0;
+	if (type >= 'A' && type <= 'Z')
+	    entry->type |= N_EXT;
+	entry->symbol = strdup(symbol);
+	entry->next = list;
+	list = entry;
+	nsym++;
+	stringsize += strlen(symbol) + 1;
+    }
+    symsize = nsym * sizeof(struct nlist);
+    size = symsize + stringsize;
+    namelist = (struct nlist *) xmalloc(size);
+    stringpos = strings = ((char *) namelist) + symsize;
+    for (i = 0; i < nsym; i++) {
+	entry = list;
+	list = list->next;
+	namelist[i].n_value = entry->address;
+	namelist[i].n_type = entry->type;
+	namelist[i].n_un.n_strx = stringpos - strings;
+	strcpy(stringpos, entry->symbol);
+	stringpos += strlen(entry->symbol) + 1;
+	free(entry->symbol);
+	free(entry);
+    }
+    qsort(namelist, nsym, sizeof(struct nlist), nlist_addrcmp);
+    return(0);
+}
+
+/*
+ * funcs and ttys are sorted on address/rdev
+ */
+int
+nlist_addrcmp(const void *p1, const void *p2)
+{
+    struct nlist *s1 = (struct nlist *) p1;
+    struct nlist *s2 = (struct nlist *) p2;
+
+    return s1->n_value < s2->n_value ? -1 : s1->n_value > s2->n_value ? 1 : 0;
+}
+
 void
 make_vartbl(void)
 {
